# Installing from PyPI


- TuxRun requires Python 3.6 or newer.
- The default runtime is podman, you should install it.

To install TuxRun on your system globally:

```shell
sudo pip3 install -U tuxrun
```

To install tuxrun to your home directory at ~/.local/bin:

```shell
pip3 install -U --user tuxrun
```

To upgrade TuxRun to the latest version, run the same command you ran to
install it.
